.. natsort documentation master file, created by
   sphinx-quickstart on Thu Jul 17 21:01:29 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

natsort: Simple yet flexible natural sorting in Python.
=======================================================

Contents:

.. toctree::
   :maxdepth: 2
   :numbered:

   intro.rst
   howitworks.rst
   examples.rst
   api.rst
   shell.rst
   changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

